package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IFillSymbol;
import com.esri.arcgis.display.MultiLayerFillSymbol;
import com.esri.arcgis.display.SimpleFillSymbol;
import com.esri.arcgis.display.MarkerFillSymbol;
import com.esri.arcgis.display.PictureFillSymbol;
import com.esri.arcgis.display.esriSimpleMarkerStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads multi layer line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerFillSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerFillSymbolReader.class);

    /**
     * Private member.
     */
    private MultiLayerFillSymbol symbol;

    public MultiLayerFillSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerFillSymbol) {
            this.symbol = (MultiLayerFillSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerFillSymbol!");
        }
    }


    public MultiLayerFillSymbolReader(IFillSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerFillSymbol) {
            this.symbol = (MultiLayerFillSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerFillSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        for(int i = 0; i < symbol.getLayerCount(); i++) {
            ISymbol sym = (ISymbol)symbol.getLayer(i);

            FillSymbolReader fsr = new FillSymbolReader();
            if(fsr.canRead(sym)) {
                fsr.setSymbol(sym);
                fsr.setParent(parent);
                fsr.setUtil(util);
                fsr.read();
            }
            else {
                logger.debug("The type of " + sym.getClass().toString() +
                             " is not implemented!");
            }
        }
        return parent;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
